PCB Environment: Logger Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Static Public Attributes
Logger Class Reference

## Public Member Functions
void | Error (const std::string &s)
void | Warn (const std::string &s)
void | Info (const std::string &s)
void | Notice (const std::string &s)
void | Debug (const std::string &s)
void | Trace (const std::string &s)
bool | visible (LogLevel v) const
void | setLevel (const std::string &)
void | setDefaultLevel (const std::string &)
void | setLevel (LogLevel)
void | setPrefix (const std::string &)
void | setTarget (LogLevel, const std::string &path)
int | indent (int n)

## Static Public Member Functions
static Logger & | get ()
static char | levelChar (LogLevel)
static LogLevel | level (const std::string_view name)
static std::string | nowString ()
static std::string | formatDurationUS (uint64_t us)
static std::string | formatMask (uint32_t)

## Static Public Attributes
static constexpr const uint | NumLevels = uint(LogLevel::COUNT)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Log.hpp